@@ -1,5 +1,5 @@
 #cheese
 
 class Variables:
-    release = "22.05.04.12.13"
+    release = "1.2.18"
     documentation = "https://kubaboi.github.io/CheeseFramework/"
